@@ -50,8 +50,8 @@
 ## magnitude (> 2^53) can also be affected from precision loss.
 ##
 ## For the creation of interval matrices, arguments may be provided as (1) cell 
-## arrays with arbitrary/mixed types, (2) numeric matrices, or (3) string
-## column vectors.  Scalar values do broadcast.
+## arrays with arbitrary/mixed types, (2) numeric matrices, or (3) strings.  
+## Scalar values do broadcast.
 ##
 ## Non-standard behavior: This class constructor is not described by IEEE 1788,
 ## however it implements both IEEE 1788 functions numsToInterval and
@@ -108,7 +108,7 @@ if (nargin == 1)
         return
     endif
     if (ischar (l))
-        l = cellstr (l);
+        l = __split_interval_literals__ (l);
     endif
     if (iscell (l))
         ## Parse interval literals
@@ -181,10 +181,10 @@ if (nargin == 1)
 endif
 
 if (ischar (l))
-    l = cellstr (lower (l));
+    l = __split_interval_literals__ (lower (l));
 endif
 if (ischar (u))
-    u = cellstr (lower (u));
+    u = __split_interval_literals__ (lower (u));
 endif
 
 if (not (size_equal (l, u)))
@@ -596,9 +596,26 @@ endfunction
 %!  assert (sup (infsup ("[e, pi]")), pi + 2 * eps);
 %!  assert (inf (infsup ("[6/9, 6e1/9]")), 2 / 3);
 %!  assert (sup (infsup ("[6/9, 6e1/9]")), 20 / 3);
+%!test "corner cases";
+%!  assert (inf (infsup (",")), -inf);
+%!  assert (sup (infsup (",")), +inf);
+%!  assert (inf (infsup ("[,]")), -inf);
+%!  assert (sup (infsup ("[,]")), +inf);
+%!  assert (inf (infsup ("[, 3]")), -inf);
+%!  assert (sup (infsup ("[, 3]")), 3);
+%!  assert (inf (infsup ("", "3")), -inf);
+%!  assert (sup (infsup ("", "3")), 3);
+%!  assert (inf (infsup ("[2, ]")), 2);
+%!  assert (sup (infsup ("[2, ]")), inf);
+%!  assert (inf (infsup ("2", "")), 2);
+%!  assert (sup (infsup ("2", "")), inf);
 %!test "decimal vector";
 %!  assert (inf (infsup (["0.1"; "0.2"; "0.3"])), [0.1 - eps / 16; 0.2 - eps / 8; 0.3]);
 %!  assert (sup (infsup (["0.1"; "0.2"; "0.3"])), [0.1; 0.2; 0.3 + eps / 8]);
+%!  assert (inf (infsup ("0.1; 0.2; 0.3")), [0.1 - eps / 16; 0.2 - eps / 8; 0.3]);
+%!  assert (sup (infsup ("0.1; 0.2; 0.3")), [0.1; 0.2; 0.3 + eps / 8]);
+%!  assert (inf (infsup ("0.1\n0.2\n0.3")), [0.1 - eps / 16; 0.2 - eps / 8; 0.3]);
+%!  assert (sup (infsup ("0.1\n0.2\n0.3")), [0.1; 0.2; 0.3 + eps / 8]);
 %!test "cell array with mixed boundaries";
 %!  assert (inf (infsup ({"0.1", 42; "e", "3.2/8"}, {"0xffp2", "42e1"; "pi", 2})), [0.1 - eps / 16, 42; e, 0.4 - eps / 4]);
 %!  assert (sup (infsup ({"0.1", 42; "e", "3.2/8"}, {"0xffp2", "42e1"; "pi", 2})), [1020, 420; pi + 2 * eps, 2]);
